from xml.sax.handler import ContentHandler

IS_A = 0
PART_OF = 1

def get_intid(goid):
    return int(goid[3:])


class GOHandler(ContentHandler):
    def __init__(self,):
        # create flags
        self.isId, self.isType,self.isIsA, self.isPartOf, self.isAldId, self.isConsider, self.isName, self.isNameSpace , self.isDefStr, self.isObsolete= 0,0,0,0,0,0,0,0,0,0
        self.inTerm = 0
        self.inDef = 0
        self.inRelationship = 0
        self.edges = []
        self.terms = []
        self.GOAlt = dict()
        self.GONameSpace = dict()
        self.GOName = dict()
        self.GODef= dict()
        self.GOObsolete = set()
        self.id = ''
        
    def startElement(self, name, attrs):
        if name == 'term':
            self.inTerm = 1
        if name == 'def':
            self.inDef = 1
        
        if self.inTerm == 1:
            if self.inRelationship == 1:
                if name == 'type':        
                    self.isType = 1
                    self.type = ''
                elif name == 'to' and self.type=='part_of':
                    self.isPartOf = 1
                    self.partof = ''
            else:
                if name == 'relationship':
                    self.inRelationship = 1
                elif name == 'id':        
                    self.isId = 1
                    self.id = ''
                elif name == 'is_a':
                    self.isIsA = 1
                    self.isa = ''
                elif name == 'part_of':
                    self.isPartOf = 1
                    self.partof = ''
                elif name == 'is_obsolete':
                    self.isObsolete = 1
                    self.obsolete = ''
                elif name == 'alt_id':
                    self.isAldId = 1
                    self.altId = ''
                elif name == 'consider' or name == 'replaced_by':
                    self.isConsider = 1
                    self.consider = ''
                elif name == 'name' and not self.inDef:
                    self.isName = 1
                    self.name = ''
                elif name == 'namespace':
                    self.isNameSpace = 1
                    self.nameSpace = ''
                elif name == 'defstr':
                    self.isDefStr = 1
                    self.defStr = ''

    
    def endElement(self, name):
        if name == 'def':
            self.inDef = 0
            
        if self.inTerm == 1:
            if self.inRelationship == 1:
                if name == 'relationship':
                    self.inRelationship = 0
                elif name == 'type':
                    self.isType=0
                elif name == 'to' and self.type=='part_of':
                    self.isPartOf = 0
                    self.edges.append( (self.id, get_intid(self.partof), PART_OF ) )
            else:
                if name == 'term':
                    self.terms.append(self.id)
                    self.inTerm = 0
                elif name == 'id':
                    self.isId = 0
                    self.id = get_intid(self.id)
                    self.GODef[self.id]=''
                elif name == 'is_a':
                    self.isIsA = 0
                    self.edges.append( (self.id, get_intid(self.isa), IS_A ) )
                elif name == 'part_of':
                    self.isPartOf = 0
                    self.edges.append( (self.id, get_intid(self.partof), PART_OF ) )
                elif name == 'is_obsolete':
                    self.isObsolete = 0
                    self.GOObsolete.add(self.id)
                elif name == 'alt_id':
                    self.isAldId = 0
                    self.GOAlt[get_intid(self.altId)]=self.id
                elif name == 'consider' or name == 'replaced_by':
                    self.isConsider = 0
                    self.GOAlt[self.id]=get_intid(self.consider)
                elif name == 'name':
                    self.isName = 0 
                    self.GOName[self.id]=self.name
                elif name == 'namespace':
                    self.isNameSpace = 0
                    self.GONameSpace[self.id]=self.nameSpace
                elif name == 'defstr':
                    self.isDefStr = 0
                    self.GODef[self.id]=self.defStr
    
    def characters(self, ch):
        if self.isId == 1:
            self.id += ch
        elif self.isType == 1:
            self.type += ch
        elif self.isIsA == 1:
            self.isa += ch
        elif self.isPartOf == 1:
            self.partof += ch
        elif self.isObsolete == 1:
            self.obsolete += ch            
        elif self.isAldId == 1:
            self.altId += ch
        elif self.isConsider == 1:
            self.consider += ch
        elif self.isName == 1:
            self.name += ch
        elif self.isNameSpace == 1:
            self.nameSpace += ch
        elif self.isDefStr == 1:
            self.defStr += ch
            




"""
app.py

AIGO is a python library for
the Analysis and Inter-comparison of Gene Ontology functional annotations.
see (http://code.google.com/p/aigo).
        
Created by Michael Defoin-Platel on 21/02/2010.
Copyright (c) 2010. All rights reserved.

AIGO is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from pylab import *
import os

import wx
from ObjectListView import FastObjectListView, ColumnDefn

import pydoc


from PIL import Image as Image
from AIGO.gui import project, popups, grid, gui


from AIGO import allAspect
from AIGO.Statistics import registerStat
from AIGO.Plot import PlotFA, registerPlot
from AIGO.IO import IOType


def PNGtoBitmap(fileName, resize=None):

    mypilimage = Image.open(fileName, "r")
    if resize:
        #mypilimage.resize(resize, , Image.ANTIALIAS)
        mypilimage.thumbnail( resize, Image.ANTIALIAS)
    mywximage = wx.EmptyImage(mypilimage.size[0],mypilimage.size[1])
    mywximage.SetData(mypilimage.convert("RGB").tostring())
    mywximage.SetAlphaData(mypilimage.convert("RGBA").tostring()[3::4])
    return wx.BitmapFromImage(mywximage)


def  setNewID(wid):
    ID=wx.NewId()
    wid.SetId(ID)
    return ID





class AIGOApp(wx.PySimpleApp):
    
    def OnInit(self, doSplash=False):

        #-----------------------------------------------------
        #                     IMAGES
        #-----------------------------------------------------
        import os
        import AIGO.gui
        self.guiDir=os.path.dirname(AIGO.gui.__file__)
        self.AIGOBmp = PNGtoBitmap("%s/AIGO.png" % self.guiDir)
        self.checkBmp = PNGtoBitmap("%s/check.png" % self.guiDir, resize=[17,13])
        self.crossBmp = PNGtoBitmap("%s/cross.png" % self.guiDir, resize=[13,13])

        self.icon = wx.EmptyIcon()
        self.icon.CopyFromBitmap(self.AIGOBmp)



        #-----------------------------------------------------
        #                     SPLASH
        #-----------------------------------------------------
        if doSplash:
            splashStyle = wx.SPLASH_CENTRE_ON_SCREEN | wx.SPLASH_TIMEOUT
            splashDuration = 2000 # milliseconds
            splash=wx.SplashScreen(self.AIGOBmp, splashStyle,splashDuration, None)
            splash.Show(True)
        
        self.popup = popups.Popup()

        #-----------------------------------------------------
        #                     FRAMES
        #-----------------------------------------------------

        #Create main frame
        self.frame = gui.AIGOFrame(None, -1, "")
        self.frame.Show(True)
        self.SetTopWindow(self.frame)
        self.frame.SetIcon(self.icon)
        self.statusField=self.frame.statusbar.GetFields()

        #Create new project frame
        self.npFrame = gui.NewProjectFrame(self.frame, -1, "New Project")
        self.npFrame.Show(False)
        self.npFrame.SetIcon(self.icon)

        #Create new functional annotation frame
        self.FAFrame = gui.FAFrame(self.frame, -1, "Add Functional Annotation")
        self.FAFrame.combo_box_FileType.Clear()
        self.FAFrame.combo_box_FileType.AppendItems(sort(IOType.keys()))
        self.FAFrame.Show(False)
        self.FAFrame.SetIcon(self.icon)

        #Create view annotation set frame
        self.ViewFrame = gui.ViewFrame(self.frame, -1, "View gene product annotations")
        self.ViewFrame.Show(False)
        self.ViewFrame.SetIcon(self.icon)

        #-----------------------------------------------------
        #                     LIST FA
        #-----------------------------------------------------
        self.frame.notebook.list_FA.InsertColumn(0, "Status")
        self.frame.notebook.list_FA.InsertColumn(1, "Name")
        self.frame.notebook.list_FA.InsertColumn(2, "File", wx.LIST_FORMAT_RIGHT)
        self.frame.notebook.list_FA.InsertColumn(3, "File Type")

        self.frame.notebook.list_FA.SetColumnWidth(0, 100)
        self.frame.notebook.list_FA.SetColumnWidth(1, 200)
        self.frame.notebook.list_FA.SetColumnWidth(2, 400)
        self.frame.notebook.list_FA.SetColumnWidth(3, 100)


        #-----------------------------------------------------
        #                     STATISTICS
        #-----------------------------------------------------
        self.workflow=list()
        self.viewStat=dict()
        for statistics in registerStat.getAll():
            if hasattr(self.frame.notebook, 'checkbox_%s' % statistics):
                self.viewStat[statistics]=True
                self.workflow.append(statistics)

        self.frame.notebook.button_Export.SetLabel("Export")

        for statistics in self.viewStat:
            bmp=getattr(self.frame.notebook, 'bitmap_%s' % statistics)
            bmp.SetBitmap(self.crossBmp)

        #-----------------------------------------------------
        #                     COMPARE
        #-----------------------------------------------------
        self.frame.notebook.button_Update_Venn.SetLabel("Venn diagram")
        self.frame.notebook.button_Update_FuncSim.SetLabel("Functional Similarity")
                
        for name in ["FA1", "FA2"]:
            lst=getattr(self.frame.notebook, 'combo_box_Compare_%s' % name)
            lst.SetName(name)

        compareColumns = [
            ColumnDefn("Gene Product",            "left", 300, valueGetter="gp", minimumWidth=40, maximumWidth=500),
            ColumnDefn("Annotations in first FA", "right", 250, valueGetter="nb1", minimumWidth=40, maximumWidth=300),
            ColumnDefn("Annotations in second FA", "right", 250, valueGetter="nb2", minimumWidth=40, maximumWidth=300),
            ColumnDefn("Functional Similarity",   "right", 200, valueGetter="funcSim", minimumWidth=40)
            ]

        for aspect in allAspect:
            bmp=getattr(self.frame.notebook, 'bitmap_%s' % aspect)
            size=bmp.GetSize().Get()
            bmp.SetBitmap(self.AIGOBmp)
            
            btn=getattr(self.frame.notebook, 'button_Compare_%s' % aspect)
            btn.SetLabel("View")

            lst=getattr(self.frame.notebook, 'list_ctrl_Compare_%s' % aspect)
            lst.SetName(aspect)

            lst.SetColumns(compareColumns)

            btn=getattr(self.frame.notebook, 'button_Compare_%s' % aspect)
            btn.SetName(aspect)


        #-----------------------------------------------------
        #                     PLOT
        #-----------------------------------------------------

        #-----------------------------------------------------
        #                     EVENTS
        #-----------------------------------------------------
        
        # Menu Events
        #
        #wx.EVT_MENU(self, gui.ID_BLURB, self.MenuBlurb)
        #self.frame.SetAcceleratorTable(wx.AcceleratorTable([
        #                (wx.ACCEL_NORMAL, wx.WXK_F1, gui.ID_EXIT),
        #                (wx.ACCEL_NORMAL, wx.WXK_F2, gui.ID_BLURB),
        #                ]))

        #Menu
        wx.EVT_MENU(self, gui.MENU_NEW,  self.MenuNew)
        wx.EVT_MENU(self, gui.MENU_OPEN, self.MenuOpen)
        wx.EVT_MENU(self, gui.MENU_SAVE, self.MenuSave)
        wx.EVT_MENU(self, gui.MENU_QUIT, self.MenuQuit)
        wx.EVT_MENU(self, gui.MENU_ABOUT, self.MenuAbout)

        #New Project        
        wx.EVT_BUTTON(self, self.npFrame.button_DirectoryChoose.GetId(),  self.OnNewProjectDirChoose)
        wx.EVT_BUTTON(self, setNewID(self.npFrame.button_NewProjectOK),     self.OnNewProjectOK)
        wx.EVT_BUTTON(self, setNewID(self.npFrame.button_NewProjectCancel), self.OnNewProjectCancel)
        
        #Data
        wx.EVT_BUTTON(self, self.frame.notebook.button_RefSetChoose.GetId(), self.OnBrowseRefSet)
        wx.EVT_BUTTON(self, setNewID(self.frame.notebook.button_RefSetLoad),   self.OnLoadRefSet)

        wx.EVT_BUTTON(self, self.frame.notebook.button_GOChoose.GetId(), self.OnBrowseGO)
        wx.EVT_BUTTON(self, setNewID(self.frame.notebook.button_GOLoad),   self.OnLoadGO)

        #Add FA
        wx.EVT_BUTTON(self, self.frame.notebook.button_AddFA.GetId(),    self.OnAddFA)
        wx.EVT_BUTTON(self, self.frame.notebook.button_RemoveFA.GetId(), self.OnRemoveFA)
        wx.EVT_BUTTON(self, self.frame.notebook.button_LoadFA.GetId(),   self.OnLoadFA)
        
        wx.EVT_BUTTON(self, self.FAFrame.button_FileChoose.GetId(), self.OnFAFileChoose)
        wx.EVT_BUTTON(self, setNewID(self.FAFrame.button_FAOK),       self.OnFAOK)
        wx.EVT_BUTTON(self, setNewID(self.FAFrame.button_FACancel),   self.OnFACancel)

        #Statistics
        wx.EVT_BUTTON(self, self.frame.notebook.button_Apply.GetId(),   self.OnStatApply)
        for statistics in registerStat.getAll():
            cb=self.frame.notebook.__dict__.get('checkbox_%s' % statistics, None)
            if cb:
                cb.SetName(statistics)
                wx.EVT_CHECKBOX(self,     cb.GetId(),  self.OnStatCheck)

        wx.EVT_BUTTON(self, setNewID(self.frame.notebook.button_Export),   self.OnStatExport)

        #Compare
        wx.EVT_BUTTON(self, setNewID(self.frame.notebook.button_Update_Venn),   self.OnUpdateVenn)
        wx.EVT_BUTTON(self, setNewID(self.frame.notebook.button_Update_FuncSim),   self.OnUpdateFuncSim)
                
        wx.EVT_SIZE(self.ViewFrame, self.OnResizeView)
        
        for name in ["FA1", "FA2"]:
            lst=getattr(self.frame.notebook, 'combo_box_Compare_%s' % name)
            wx.EVT_COMBOBOX(self, lst.GetId(), self.OnCompareStat)
            
        for aspect in allAspect:
            btn=getattr(self.frame.notebook, 'button_Compare_%s' % aspect)
            wx.EVT_BUTTON(self, setNewID(btn), self.OnCompareView)

            #lst=getattr(self.frame.notebook, 'list_ctrl_Compare_%s' % aspect)
            #wx.EVT_LIST_COL_CLICK(self, setNewID(lst), self.OnCompareColClick)


        #Plot
        wx.EVT_COMBOBOX(self, self.frame.notebook.combo_PlotStat.GetId(),   self.OnStatPlot)
        
        return True




import sys, time, os, datetime, traceback

class Logger:
    __state = {}
    NONE = 0
    FATAL = 1
    WARNING = 2
    INFO = 3

    ## Constructor (makes a new instance, but state is shared across all instances)
    # @param loglevel (default of 0):
    # \li 0 - turns off logging - raise RuntimeErrors/Warnings for fatal/warning messages (useful for code build on this library)
    # \li 1 - print only fatal messages
    # \li 2 - print warnings and fatal messages
    # \li 3 - info mode - prints everything
    def __init__(self, loglevel=0):
        self.__dict__ = Logger.__state
        if self.__dict__ == {}:
            self.loglevel = int(loglevel)
            self.stdout_logging = (os.name == 'posix')
            # if a PercentMessage class is currently in process, then withhold
            # info messages
            self.percentMessage = False


    def timenow(self):
        return time.strftime("[%H:%M:%S] ")


    ## Log a info message
    # @param msg information message to log
    def info(self, msg, singleline=False):
        if self.loglevel==3 and not self.percentMessage:
            if self.stdout_logging and singleline:
                print "\r" + self.timenow() + "\033[32;1minfo:\033[0m " + msg,
                sys.stdout.flush()
            elif self.stdout_logging:
                print self.timenow() + "\033[32;1minfo:\033[0m " + msg
            else:
                print self.timenow() + "INFO: "+msg


    ## Log a warning message (bad, but not bad enough to stop the program)
    # @param error Error message to log
    # @param exception If true this method will print the last stacktrace as well
    def handleWarning(self, error, exception=False):
        if self.loglevel > 1:
            # We need a newline if we're printing percent messages
            if self.percentMessage:
                print
            if self.stdout_logging:
                print self.timenow() + "\033[33;1mwarning:\033[0m " + error
            else:
                print self.timenow() + "WARNING: "+error
            if exception:
                self.printExceptionStack()                
        elif self.loglevel == 0:
            raise RuntimeWarning, error


    ## Log a message concerning a fatal error that will cause this program to terminate.  The function then
    # terminates the program.
    # @param fatal The message containing a description of the fatal conditions.
    # @param exception If true this method will print the last stacktrace as well    
    def handleFatal(self, fatal, exception=False):
        if self.loglevel > 0:
            if self.stdout_logging:
                print self.timenow() + "\033[31;1mfatal:\033[0m " + fatal
            else:
                print self.timenow() + "FATAL: "+fatal
            if exception:
                self.printExceptionStack()
            #sys.exit(1)
            raise RuntimeError, fatal
        else:
            raise RuntimeError, fatal


    ## Print the most recent exception's stacktrace
    def printExceptionStack(self):
        traceback.print_exc()
                        

                                                                                
## Class to handle percent logging to terminal.  Note that once you call update for the first time,
# Logger info messages will be suppressed until you call finished.
# p = LogProgress(totalsize)
# p.update() # run many times
# p.finished()
class LogProgress:
    def __init__(self, size):
        self.size = float(size)
        self.start = None
        self.logger = Logger()
        self.current = 0
        self.index = 0


    def update(self):
        if self.start is None:
            self.start = time.time()
        self.current += 1
        self.index += 1

        if self.size > 100000 and self.index != 10000:
            return
        if self.index == 10000:
            self.index = 0

        ratio = float(self.current) / self.size
        age = float(self.age())
        finish = self.prettyTime((age / ratio) - age) # age/ratio = total time
        line = "%s percent done at point %i (estimated finish in %s)" % (str(ratio * 100), self.current, finish)
        while len(line) < 70:
            line += "  "

        # *we* should be able to print info, no one else should
        self.logger.percentMessage = False                            
        self.logger.info(line,True)
        self.logger.percentMessage = True


    def age(self):
        return time.time() - self.start


    def prettyTime(self, seconds):
        seconds = int(seconds)
        return str(datetime.timedelta(seconds=seconds))


    def finished(self):
        self.logger.percentMessage = False                
        self.logger.info("done")
        self.logger.info("finished in %s" % self.prettyTime(self.age()))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# generated by wxGlade 0.6.3 on Sun Jun 27 17:35:48 2010

import wx, os

from ObjectListView import FastObjectListView

from AIGO.gui.grid import StatisticsGrid

class ViewPanel(wx.Panel):
    def __init__(self, *args, **kwds):
        # content of this block not found: did you rename this class?
        pass

    def __set_properties(self):
        # content of this block not found: did you rename this class?
        pass

    def __do_layout(self):
        # content of this block not found: did you rename this class?
        pass

# end of class ViewPanel


class ViewFrame(wx.MDIChildFrame):
    def __init__(self, *args, **kwds):
        # begin wxGlade: ViewFrame.__init__
        kwds["style"] = wx.MINIMIZE_BOX|wx.MAXIMIZE_BOX|wx.STAY_ON_TOP|wx.RESIZE_BORDER|wx.FULL_REPAINT_ON_RESIZE
        wx.Frame.__init__(self, *args, **kwds)
        self.panel_2 = wx.Panel(self, -1)
        self.bitmap = wx.StaticBitmap(self.panel_2, -1, wx.NullBitmap, style=wx.FULL_REPAINT_ON_RESIZE)

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: ViewFrame.__set_properties
        self.SetTitle("View gene product")
        self.bitmap.SetMinSize((500,500))
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: ViewFrame.__do_layout
        sizer_34 = wx.BoxSizer(wx.VERTICAL)
        sizer_35 = wx.BoxSizer(wx.VERTICAL)
        sizer_35.Add(self.bitmap, 1, wx.EXPAND|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        self.panel_2.SetSizer(sizer_35)
        sizer_34.Add(self.panel_2, 1, wx.EXPAND|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL, 0)
        self.SetSizer(sizer_34)
        sizer_34.Fit(self)
        self.Layout()
        self.Centre()
        # end wxGlade

# end of class ViewFrame


class FAFrame(wx.Frame):
    def __init__(self, *args, **kwds):
        # begin wxGlade: FAFrame.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, *args, **kwds)
        self.panel_1 = wx.Panel(self, -1)
        self.sizer_11_staticbox = wx.StaticBox(self.panel_1, -1, "")
        self.label_FA = wx.StaticText(self.panel_1, -1, "FA name")
        self.box_FA = wx.TextCtrl(self.panel_1, -1, "", style=wx.HSCROLL)
        self.label_FA_File = wx.StaticText(self.panel_1, -1, "Choose file")
        self.box_File = wx.TextCtrl(self.panel_1, -1, "", style=wx.HSCROLL)
        self.button_FileChoose = wx.Button(self.panel_1, -1, "&Browse", style=wx.BU_EXACTFIT)
        self.label_FA_Type = wx.StaticText(self.panel_1, -1, "Choose file type")
        self.combo_box_FileType = wx.ComboBox(self.panel_1, -1, choices=["GO Annotation File", "Affymetrix", "Blast2GO", "ArrayIDer", "Mapping GPid GOids"], style=wx.CB_DROPDOWN)
        self.button_FAOK = wx.Button(self.panel_1, wx.ID_OK, "")
        self.button_FACancel = wx.Button(self.panel_1, wx.ID_CANCEL, "")

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: FAFrame.__set_properties
        self.SetTitle("New Functional Annotation")
        self.label_FA.SetMinSize((100, 19))
        self.box_FA.SetMinSize((360, 29))
        self.label_FA_File.SetMinSize((100, 19))
        self.box_File.SetMinSize((280, 29))
        self.combo_box_FileType.SetSelection(1)
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: FAFrame.__do_layout
        sizer_2 = wx.BoxSizer(wx.VERTICAL)
        sizer_8 = wx.BoxSizer(wx.VERTICAL)
        sizer_7_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_11 = wx.StaticBoxSizer(self.sizer_11_staticbox, wx.VERTICAL)
        sizer_4_copy_2 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_4_copy_1 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_5_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_5_copy.Add(self.label_FA, 0, 0, 0)
        sizer_5_copy.Add(self.box_FA, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_11.Add(sizer_5_copy, 0, wx.ALL|wx.EXPAND|wx.ALIGN_CENTER_VERTICAL|wx.SHAPED, 10)
        sizer_4_copy_1.Add(self.label_FA_File, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy_1.Add(self.box_File, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy_1.Add(self.button_FileChoose, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 10)
        sizer_11.Add(sizer_4_copy_1, 0, wx.ALL, 10)
        sizer_4_copy_2.Add(self.label_FA_Type, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy_2.Add(self.combo_box_FileType, 0, wx.ADJUST_MINSIZE, 0)
        sizer_11.Add(sizer_4_copy_2, 0, wx.ALL|wx.ALIGN_RIGHT, 10)
        sizer_8.Add(sizer_11, 0, wx.ALL|wx.EXPAND, 10)
        sizer_7_copy.Add(self.button_FAOK, 0, wx.BOTTOM|wx.ADJUST_MINSIZE, 10)
        sizer_7_copy.Add(self.button_FACancel, 0, wx.RIGHT|wx.BOTTOM|wx.ADJUST_MINSIZE, 10)
        sizer_8.Add(sizer_7_copy, 0, wx.ALIGN_RIGHT|wx.ALIGN_BOTTOM, 390)
        self.panel_1.SetSizer(sizer_8)
        sizer_2.Add(self.panel_1, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_2)
        sizer_2.Fit(self)
        self.Layout()
        self.Centre()
        # end wxGlade

# end of class FAFrame


class AIGOnotebook(wx.Notebook):
    def __init__(self, *args, **kwds):
        # begin wxGlade: AIGOnotebook.__init__
        kwds["style"] = 0
        wx.Notebook.__init__(self, *args, **kwds)
        self.notebook_Plot = wx.Panel(self, -1)
        self.notebook_Compare = wx.Panel(self, -1)
        self.notebook_Compare_Aspect = wx.Notebook(self.notebook_Compare, -1, style=0)
        self.notebook_Compare_Aspect_pane_4 = wx.Panel(self.notebook_Compare_Aspect, -1)
        self.notebook_Compare_Aspect_pane_3 = wx.Panel(self.notebook_Compare_Aspect, -1)
        self.notebook_Compare_Aspect_pane_2 = wx.Panel(self.notebook_Compare_Aspect, -1)
        self.notebook_1_pane_1 = wx.Panel(self.notebook_Compare_Aspect, -1)
        self.notebook_Analysis = wx.Panel(self, -1)
        self.notebook_Statistics = wx.Notebook(self.notebook_Analysis, -1, style=wx.NB_LEFT)
        self.notebook_cellular_component = wx.Panel(self.notebook_Statistics, -1)
        self.notebook_molecular_function = wx.Panel(self.notebook_Statistics, -1)
        self.notebook_biological_process = wx.Panel(self.notebook_Statistics, -1)
        self.notebook_All_aspects_of_GO = wx.Panel(self.notebook_Statistics, -1)
        self.notebook_Data = wx.Panel(self, -1)
        self.sizer_GP_staticbox = wx.StaticBox(self.notebook_Data, -1, "Gene Products")
        self.sizer_FA_staticbox = wx.StaticBox(self.notebook_Data, -1, "Functional Annotations")
        self.sizer_16_staticbox = wx.StaticBox(self.notebook_Analysis, -1, "Statistics")
        self.sizer_27_copy_1_staticbox = wx.StaticBox(self.notebook_Compare, -1, "Select one or two Functional Annotations")
        self.sizer_31_staticbox = wx.StaticBox(self.notebook_Compare, -1, "Update information")
        self.sizer_27_copy_staticbox = wx.StaticBox(self.notebook_1_pane_1, -1, "")
        self.sizer_27_copy_copy_staticbox = wx.StaticBox(self.notebook_Compare_Aspect_pane_2, -1, "")
        self.sizer_27_copy_copy_1_staticbox = wx.StaticBox(self.notebook_Compare_Aspect_pane_3, -1, "")
        self.sizer_27_copy_copy_2_staticbox = wx.StaticBox(self.notebook_Compare_Aspect_pane_4, -1, "")
        self.sizer_23_staticbox = wx.StaticBox(self.notebook_Plot, -1, "")
        self.sizer_GO_staticbox = wx.StaticBox(self.notebook_Data, -1, "Gene Ontology")
        self.label_GO = wx.TextCtrl(self.notebook_Data, -1, "Choose the Gene Ontology", style=wx.TE_READONLY|wx.NO_BORDER)
        self.box_GO = wx.TextCtrl(self.notebook_Data, -1, "", style=wx.HSCROLL)
        self.button_GOChoose = wx.Button(self.notebook_Data, -1, "&Browse", style=wx.BU_EXACTFIT)
        self.button_GOLoad = wx.Button(self.notebook_Data, wx.ID_OPEN, "", style=wx.BU_EXACTFIT)
        self.radio_btn_GO = wx.RadioBox(self.notebook_Data, -1, "OBO format", choices=["XML", "Text"], majorDimension=1, style=wx.RA_SPECIFY_ROWS)
        self.checkbox_GO = wx.CheckBox(self.notebook_Data, -1, "Read previously serialised version")
        self.label_RefSet = wx.TextCtrl(self.notebook_Data, -1, "Choose the set of gene products", style=wx.TE_READONLY|wx.NO_BORDER)
        self.box_RefSet = wx.TextCtrl(self.notebook_Data, -1, "", style=wx.HSCROLL)
        self.button_RefSetChoose = wx.Button(self.notebook_Data, -1, "B&rowse", style=wx.BU_EXACTFIT)
        self.button_RefSetLoad = wx.Button(self.notebook_Data, wx.ID_OPEN, "", style=wx.BU_EXACTFIT)
        self.radio_btn_RefSet = wx.RadioBox(self.notebook_Data, -1, "File format", choices=["Fasta", "Text"], majorDimension=1, style=wx.RA_SPECIFY_ROWS)
        self.button_AddFA = wx.Button(self.notebook_Data, wx.ID_ADD, "")
        self.button_RemoveFA = wx.Button(self.notebook_Data, wx.ID_REMOVE, "")
        self.list_FA = wx.ListCtrl(self.notebook_Data, -1, style=wx.LC_REPORT|wx.SUNKEN_BORDER)
        self.button_LoadFA = wx.Button(self.notebook_Data, -1, "&Load")
        self.checkbox_unconnected = wx.CheckBox(self.notebook_Analysis, -1, "Obsolescence")
        self.label_unconnected = wx.StaticText(self.notebook_Analysis, -1, "Proportion of obsoletete annotations in annotation sets for which not alternative have been provided", style=wx.ALIGN_RIGHT)
        self.bitmap_unconnected = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_removeUnconnected = wx.CheckBox(self.notebook_Analysis, -1, "Remove Obsolete")
        self.label_removeUnconnected = wx.StaticText(self.notebook_Analysis, -1, "Remove obsolete annotations in all annotations sets", style=wx.ALIGN_RIGHT)
        self.bitmap_removeUnconnected = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_coverage = wx.CheckBox(self.notebook_Analysis, -1, "Coverage")
        self.label_coverage = wx.StaticText(self.notebook_Analysis, -1, "Proportion of gene products being annotated to at least on term", style=wx.ALIGN_RIGHT)
        self.bitmap_coverage = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_richness = wx.CheckBox(self.notebook_Analysis, -1, "Richness")
        self.label_richness = wx.StaticText(self.notebook_Analysis, -1, "Proportion of the terms in GO being assigned to at least one term", style=wx.ALIGN_RIGHT)
        self.bitmap_richness = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_numberAnnot = wx.CheckBox(self.notebook_Analysis, -1, "Number of Annotations")
        self.label_numberAnnot = wx.StaticText(self.notebook_Analysis, -1, "Number of annotation of an annotated gene product", style=wx.ALIGN_RIGHT)
        self.bitmap_numberAnnot = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_coherence = wx.CheckBox(self.notebook_Analysis, -1, "Coherence")
        self.label_coherence = wx.StaticText(self.notebook_Analysis, -1, "Semantic Distance of an annotation set", style=wx.ALIGN_RIGHT)
        self.bitmap_coherence = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_compactness = wx.CheckBox(self.notebook_Analysis, -1, "Compactness")
        self.label_compactness = wx.StaticText(self.notebook_Analysis, -1, "Semantic Distance between all annotation sets", style=wx.ALIGN_RIGHT)
        self.bitmap_compactness = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_specificity = wx.CheckBox(self.notebook_Analysis, -1, "Specificity")
        self.label_specificity = wx.StaticText(self.notebook_Analysis, -1, "Average number of ancestors over all the terms of an annotation set", style=wx.ALIGN_RIGHT)
        self.bitmap_specificity = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_informationContent = wx.CheckBox(self.notebook_Analysis, -1, "Information Content")
        self.label_informationContent = wx.StaticText(self.notebook_Analysis, -1, "Average Information Content over all the terms of an annotation set", style=wx.ALIGN_RIGHT)
        self.bitmap_informationContent = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_redundancy = wx.CheckBox(self.notebook_Analysis, -1, "Redundancy")
        self.label_redundancy = wx.StaticText(self.notebook_Analysis, -1, "Proportion of terms being ancestor one other term in an annotation set", style=wx.ALIGN_RIGHT)
        self.bitmap_redundancy = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.button_Apply = wx.Button(self.notebook_Analysis, wx.ID_APPLY, "")
        self.grid_All_aspects_of_GO = StatisticsGrid(self.notebook_All_aspects_of_GO, -1, size=(1, 1))
        self.grid_biological_process = StatisticsGrid(self.notebook_biological_process, -1, size=(1, 1))
        self.grid_molecular_function = StatisticsGrid(self.notebook_molecular_function, -1, size=(1, 1))
        self.grid_cellular_component = StatisticsGrid(self.notebook_cellular_component, -1, size=(1, 1))
        self.button_Export = wx.Button(self.notebook_Analysis, wx.ID_FORWARD, "")
        self.combo_box_Compare_FA1 = wx.ComboBox(self.notebook_Compare, -1, choices=[], style=wx.CB_DROPDOWN|wx.CB_READONLY)
        self.combo_box_Compare_FA2 = wx.ComboBox(self.notebook_Compare, -1, choices=[], style=wx.CB_DROPDOWN|wx.CB_READONLY)
        self.button_Update_Venn = wx.Button(self.notebook_Compare, wx.ID_REFRESH, "")
        self.button_Update_FuncSim = wx.Button(self.notebook_Compare, wx.ID_REFRESH, "")
        self.bitmap_Venn_All_aspects_of_GO = wx.StaticBitmap(self.notebook_1_pane_1, -1, wx.NullBitmap)
        self.bitmap_All_aspects_of_GO = wx.StaticBitmap(self.notebook_1_pane_1, -1, wx.NullBitmap)
        self.bitmap_FuncSim_All_aspects_of_GO = wx.StaticBitmap(self.notebook_1_pane_1, -1, wx.NullBitmap)
        self.list_ctrl_Compare_All_aspects_of_GO = FastObjectListView(self.notebook_1_pane_1, -1, style=wx.LC_REPORT|wx.LC_SINGLE_SEL|wx.LC_SORT_ASCENDING|wx.LC_HRULES|wx.SUNKEN_BORDER)
        self.button_Compare_All_aspects_of_GO = wx.Button(self.notebook_1_pane_1, wx.ID_ZOOM_IN, "")
        self.bitmap_Venn_biological_process = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_2, -1, wx.NullBitmap)
        self.bitmap_biological_process = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_2, -1, wx.NullBitmap)
        self.bitmap_FuncSim_biological_process = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_2, -1, wx.NullBitmap)
        self.list_ctrl_Compare_biological_process = FastObjectListView(self.notebook_Compare_Aspect_pane_2, -1, style=wx.LC_REPORT|wx.LC_SINGLE_SEL|wx.LC_SORT_ASCENDING|wx.LC_HRULES|wx.SUNKEN_BORDER)
        self.button_Compare_biological_process = wx.Button(self.notebook_Compare_Aspect_pane_2, wx.ID_ZOOM_IN, "")
        self.bitmap_Venn_molecular_function = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_3, -1, wx.NullBitmap)
        self.bitmap_molecular_function = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_3, -1, wx.NullBitmap)
        self.bitmap_FuncSim_molecular_function = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_3, -1, wx.NullBitmap)
        self.list_ctrl_Compare_molecular_function = FastObjectListView(self.notebook_Compare_Aspect_pane_3, -1, style=wx.LC_REPORT|wx.LC_SINGLE_SEL|wx.LC_SORT_ASCENDING|wx.LC_HRULES|wx.SUNKEN_BORDER)
        self.button_Compare_molecular_function = wx.Button(self.notebook_Compare_Aspect_pane_3, wx.ID_ZOOM_IN, "")
        self.bitmap_Venn_cellular_component = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_4, -1, wx.NullBitmap)
        self.bitmap_cellular_component = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_4, -1, wx.NullBitmap)
        self.bitmap_FuncSim_cellular_component = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_4, -1, wx.NullBitmap)
        self.list_ctrl_Compare_cellular_component = FastObjectListView(self.notebook_Compare_Aspect_pane_4, -1, style=wx.LC_REPORT|wx.LC_SINGLE_SEL|wx.LC_SORT_ASCENDING|wx.LC_HRULES|wx.SUNKEN_BORDER)
        self.button_Compare_cellular_component = wx.Button(self.notebook_Compare_Aspect_pane_4, wx.ID_ZOOM_IN, "")
        self.label_PlotStatistics = wx.StaticText(self.notebook_Plot, -1, "Select a statistics")
        self.combo_PlotStat = wx.ComboBox(self.notebook_Plot, -1, choices=[], style=wx.CB_DROPDOWN)
        self.label_2 = wx.StaticText(self.notebook_Plot, -1, "Plot type")
        self.combo_PlotType = wx.ComboBox(self.notebook_Plot, -1, choices=[], style=wx.CB_DROPDOWN)
        self.label_PlotStatistics_copy = wx.StaticText(self.notebook_Plot, -1, "Select Functional Annotations")
        self.list_PlotFA = wx.ListBox(self.notebook_Plot, -1, choices=[], style=wx.LB_MULTIPLE|wx.LB_HSCROLL|wx.LB_NEEDED_SB)
        self.bitmap_Plot = wx.StaticBitmap(self.notebook_Plot, -1, wx.NullBitmap, style=wx.RAISED_BORDER)

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: AIGOnotebook.__set_properties
        self.AddPage(self.notebook_Data, "Data")
        self.AddPage(self.notebook_Analysis, "Analysis")
        self.AddPage(self.notebook_Compare, "Compare")
        self.AddPage(self.notebook_Plot, "Plot")
        self.label_GO.SetMinSize((280, 29))
        self.label_GO.SetBackgroundColour(wx.Colour(241, 238, 238))
        self.box_GO.SetMinSize((280, 29))
        self.radio_btn_GO.Enable(False)
        self.radio_btn_GO.SetSelection(0)
        self.checkbox_GO.Hide()
        self.label_RefSet.SetMinSize((280, 29))
        self.label_RefSet.SetBackgroundColour(wx.Colour(241, 238, 238))
        self.box_RefSet.SetMinSize((280, 29))
        self.radio_btn_RefSet.SetSelection(0)
        self.button_AddFA.Enable(False)
        self.button_RemoveFA.Enable(False)
        self.notebook_Data.SetBackgroundColour(wx.Colour(241, 238, 238))
        self.notebook_Data.Enable(False)
        self.checkbox_unconnected.SetValue(1)
        self.checkbox_removeUnconnected.SetValue(1)
        self.checkbox_coverage.SetValue(1)
        self.checkbox_richness.SetValue(1)
        self.checkbox_numberAnnot.SetValue(1)
        self.checkbox_coherence.SetValue(1)
        self.checkbox_compactness.SetValue(1)
        self.checkbox_specificity.SetValue(1)
        self.checkbox_informationContent.SetValue(1)
        self.checkbox_redundancy.SetValue(1)
        self.grid_All_aspects_of_GO.CreateGrid(10, 3)
        self.grid_All_aspects_of_GO.SetRowLabelSize(250)
        self.grid_All_aspects_of_GO.SetColLabelSize(30)
        self.grid_All_aspects_of_GO.EnableEditing(0)
        self.grid_biological_process.CreateGrid(10, 3)
        self.grid_biological_process.SetRowLabelSize(250)
        self.grid_biological_process.EnableEditing(0)
        self.grid_molecular_function.CreateGrid(10, 3)
        self.grid_molecular_function.SetRowLabelSize(250)
        self.grid_molecular_function.EnableEditing(0)
        self.grid_cellular_component.CreateGrid(10, 3)
        self.grid_cellular_component.SetRowLabelSize(250)
        self.grid_cellular_component.EnableEditing(0)
        self.button_Update_Venn.SetMinSize((189, 34))
        self.button_Update_FuncSim.SetMinSize((189, 34))
        self.bitmap_Venn_All_aspects_of_GO.SetMinSize((369, 280))
        self.bitmap_All_aspects_of_GO.SetMinSize((369, 280))
        self.bitmap_FuncSim_All_aspects_of_GO.SetMinSize((369, 280))
        self.list_ctrl_Compare_All_aspects_of_GO.SetMinSize((1100, 270))
        self.list_ctrl_Compare_All_aspects_of_GO.Enable(False)
        self.list_ctrl_Compare_All_aspects_of_GO.Hide()
        self.button_Compare_All_aspects_of_GO.Enable(False)
        self.button_Compare_All_aspects_of_GO.Hide()
        self.bitmap_Venn_biological_process.SetMinSize((369, 280))
        self.bitmap_biological_process.SetMinSize((369, 280))
        self.bitmap_FuncSim_biological_process.SetMinSize((369, 280))
        self.list_ctrl_Compare_biological_process.SetMinSize((1100, 270))
        self.bitmap_Venn_molecular_function.SetMinSize((369, 280))
        self.bitmap_molecular_function.SetMinSize((369, 280))
        self.bitmap_FuncSim_molecular_function.SetMinSize((369, 280))
        self.list_ctrl_Compare_molecular_function.SetMinSize((1100, 270))
        self.bitmap_Venn_cellular_component.SetMinSize((369, 280))
        self.bitmap_cellular_component.SetMinSize((369, 280))
        self.bitmap_FuncSim_cellular_component.SetMinSize((369, 280))
        self.list_ctrl_Compare_cellular_component.SetMinSize((1100, 270))
        self.notebook_Compare.Enable(False)
        self.combo_PlotType.SetMinSize((250, 31))
        self.notebook_Plot.Enable(False)
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: AIGOnotebook.__do_layout
        sizer_17 = wx.BoxSizer(wx.VERTICAL)
        sizer_24 = wx.BoxSizer(wx.VERTICAL)
        sizer_23 = wx.StaticBoxSizer(self.sizer_23_staticbox, wx.VERTICAL)
        sizer_25 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_30 = wx.BoxSizer(wx.VERTICAL)
        sizer_28 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_26 = wx.BoxSizer(wx.VERTICAL)
        sizer_26_copy_copy_2 = wx.BoxSizer(wx.VERTICAL)
        sizer_27_copy_copy_2 = wx.StaticBoxSizer(self.sizer_27_copy_copy_2_staticbox, wx.HORIZONTAL)
        sizer_26_copy_copy_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_27_copy_copy_1 = wx.StaticBoxSizer(self.sizer_27_copy_copy_1_staticbox, wx.HORIZONTAL)
        sizer_26_copy_copy = wx.BoxSizer(wx.VERTICAL)
        sizer_27_copy_copy = wx.StaticBoxSizer(self.sizer_27_copy_copy_staticbox, wx.HORIZONTAL)
        sizer_26_copy = wx.BoxSizer(wx.VERTICAL)
        sizer_27_copy = wx.StaticBoxSizer(self.sizer_27_copy_staticbox, wx.HORIZONTAL)
        sizer_27 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_31 = wx.StaticBoxSizer(self.sizer_31_staticbox, wx.HORIZONTAL)
        sizer_32 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_27_copy_1 = wx.StaticBoxSizer(self.sizer_27_copy_1_staticbox, wx.HORIZONTAL)
        sizer_10 = wx.BoxSizer(wx.VERTICAL)
        sizer_15 = wx.BoxSizer(wx.VERTICAL)
        sizer_18 = wx.BoxSizer(wx.VERTICAL)
        sizer_22 = wx.BoxSizer(wx.VERTICAL)
        sizer_21 = wx.BoxSizer(wx.VERTICAL)
        sizer_20 = wx.BoxSizer(wx.VERTICAL)
        sizer_19 = wx.BoxSizer(wx.VERTICAL)
        sizer_16 = wx.StaticBoxSizer(self.sizer_16_staticbox, wx.VERTICAL)
        grid_sizer_2 = wx.FlexGridSizer(10, 3, 0, 20)
        sizer_3 = wx.BoxSizer(wx.VERTICAL)
        sizer_FA = wx.StaticBoxSizer(self.sizer_FA_staticbox, wx.VERTICAL)
        grid_sizer_1 = wx.GridSizer(1, 2, 0, 0)
        sizer_GP = wx.StaticBoxSizer(self.sizer_GP_staticbox, wx.VERTICAL)
        sizer_12_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_4 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_GO = wx.StaticBoxSizer(self.sizer_GO_staticbox, wx.VERTICAL)
        sizer_12_copy_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_4_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_4_copy.Add(self.label_GO, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy.Add((40, 40), 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy.Add(self.box_GO, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy.Add(self.button_GOChoose, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy.Add(self.button_GOLoad, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_GO.Add(sizer_4_copy, 0, wx.ALL, 5)
        sizer_12_copy_copy.Add((400, 46), 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_12_copy_copy.Add(self.radio_btn_GO, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL, 5)
        sizer_12_copy_copy.Add(self.checkbox_GO, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_GO.Add(sizer_12_copy_copy, 0, wx.ALL, 5)
        sizer_3.Add(sizer_GO, 0, wx.ALL|wx.EXPAND, 5)
        sizer_4.Add(self.label_RefSet, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4.Add((40, 40), 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4.Add(self.box_RefSet, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4.Add(self.button_RefSetChoose, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4.Add(self.button_RefSetLoad, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_GP.Add(sizer_4, 0, wx.ALL, 5)
        sizer_12_copy.Add((400, 46), 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_12_copy.Add(self.radio_btn_RefSet, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL, 5)
        sizer_GP.Add(sizer_12_copy, 0, wx.ALL, 5)
        sizer_3.Add(sizer_GP, 0, wx.ALL|wx.EXPAND, 5)
        grid_sizer_1.Add(self.button_AddFA, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_1.Add(self.button_RemoveFA, 0, wx.ADJUST_MINSIZE, 0)
        sizer_FA.Add(grid_sizer_1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 10)
        sizer_FA.Add(self.list_FA, 1, wx.EXPAND, 0)
        sizer_FA.Add(self.button_LoadFA, 0, wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 0)
        sizer_3.Add(sizer_FA, 1, wx.ALL|wx.EXPAND|wx.ADJUST_MINSIZE, 5)
        self.notebook_Data.SetSizer(sizer_3)
        grid_sizer_2.Add(self.checkbox_unconnected, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_unconnected, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 5)
        grid_sizer_2.Add(self.bitmap_unconnected, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_removeUnconnected, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_removeUnconnected, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_removeUnconnected, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_coverage, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_coverage, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_coverage, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_richness, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_richness, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_richness, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_numberAnnot, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_numberAnnot, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_numberAnnot, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_coherence, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_coherence, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_coherence, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_compactness, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_compactness, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_compactness, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_specificity, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_specificity, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_specificity, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_informationContent, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_informationContent, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_informationContent, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_redundancy, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_redundancy, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_redundancy, 0, wx.ADJUST_MINSIZE, 0)
        sizer_16.Add(grid_sizer_2, 0, wx.EXPAND, 0)
        sizer_16.Add(self.button_Apply, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        sizer_15.Add(sizer_16, 0, wx.ALL|wx.EXPAND, 5)
        sizer_19.Add(self.grid_All_aspects_of_GO, 1, wx.EXPAND|wx.ADJUST_MINSIZE, 0)
        self.notebook_All_aspects_of_GO.SetSizer(sizer_19)
        sizer_20.Add(self.grid_biological_process, 1, wx.EXPAND|wx.ADJUST_MINSIZE, 0)
        self.notebook_biological_process.SetSizer(sizer_20)
        sizer_21.Add(self.grid_molecular_function, 1, wx.EXPAND|wx.ADJUST_MINSIZE, 0)
        self.notebook_molecular_function.SetSizer(sizer_21)
        sizer_22.Add(self.grid_cellular_component, 1, wx.EXPAND|wx.ADJUST_MINSIZE, 0)
        self.notebook_cellular_component.SetSizer(sizer_22)
        self.notebook_Statistics.AddPage(self.notebook_All_aspects_of_GO, "All aspects of GO")
        self.notebook_Statistics.AddPage(self.notebook_biological_process, "Biological Process")
        self.notebook_Statistics.AddPage(self.notebook_molecular_function, "Molecular Function")
        self.notebook_Statistics.AddPage(self.notebook_cellular_component, "Cellular Component")
        sizer_18.Add(self.notebook_Statistics, 1, wx.EXPAND|wx.ADJUST_MINSIZE, 0)
        sizer_18.Add(self.button_Export, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        sizer_15.Add(sizer_18, 1, wx.ALL|wx.EXPAND|wx.ADJUST_MINSIZE, 5)
        sizer_10.Add(sizer_15, 1, wx.EXPAND, 0)
        self.notebook_Analysis.SetSizer(sizer_10)
        sizer_27_copy_1.Add(self.combo_box_Compare_FA1, 0, wx.ALL|wx.ADJUST_MINSIZE, 5)
        sizer_27_copy_1.Add(self.combo_box_Compare_FA2, 0, wx.ALL|wx.ADJUST_MINSIZE, 5)
        sizer_27.Add(sizer_27_copy_1, 1, wx.ALL|wx.EXPAND, 5)
        sizer_32.Add(self.button_Update_Venn, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        sizer_32.Add(self.button_Update_FuncSim, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        sizer_31.Add(sizer_32, 1, wx.EXPAND|wx.ALIGN_RIGHT, 0)
        sizer_27.Add(sizer_31, 1, wx.ALL|wx.EXPAND|wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL, 5)
        sizer_26.Add(sizer_27, 0, wx.EXPAND, 0)
        sizer_27_copy.Add(self.bitmap_Venn_All_aspects_of_GO, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy.Add(self.bitmap_All_aspects_of_GO, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy.Add(self.bitmap_FuncSim_All_aspects_of_GO, 1, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_26_copy.Add(sizer_27_copy, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy.Add(self.list_ctrl_Compare_All_aspects_of_GO, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy.Add(self.button_Compare_All_aspects_of_GO, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        self.notebook_1_pane_1.SetSizer(sizer_26_copy)
        sizer_27_copy_copy.Add(self.bitmap_Venn_biological_process, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy_copy.Add(self.bitmap_biological_process, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy_copy.Add(self.bitmap_FuncSim_biological_process, 1, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_26_copy_copy.Add(sizer_27_copy_copy, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy_copy.Add(self.list_ctrl_Compare_biological_process, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy_copy.Add(self.button_Compare_biological_process, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        self.notebook_Compare_Aspect_pane_2.SetSizer(sizer_26_copy_copy)
        sizer_27_copy_copy_1.Add(self.bitmap_Venn_molecular_function, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy_copy_1.Add(self.bitmap_molecular_function, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy_copy_1.Add(self.bitmap_FuncSim_molecular_function, 1, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_26_copy_copy_1.Add(sizer_27_copy_copy_1, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy_copy_1.Add(self.list_ctrl_Compare_molecular_function, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy_copy_1.Add(self.button_Compare_molecular_function, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        self.notebook_Compare_Aspect_pane_3.SetSizer(sizer_26_copy_copy_1)
        sizer_27_copy_copy_2.Add(self.bitmap_Venn_cellular_component, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy_copy_2.Add(self.bitmap_cellular_component, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy_copy_2.Add(self.bitmap_FuncSim_cellular_component, 1, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_26_copy_copy_2.Add(sizer_27_copy_copy_2, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy_copy_2.Add(self.list_ctrl_Compare_cellular_component, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy_copy_2.Add(self.button_Compare_cellular_component, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        self.notebook_Compare_Aspect_pane_4.SetSizer(sizer_26_copy_copy_2)
        self.notebook_Compare_Aspect.AddPage(self.notebook_1_pane_1, "All aspects of GO")
        self.notebook_Compare_Aspect.AddPage(self.notebook_Compare_Aspect_pane_2, "Biological Process")
        self.notebook_Compare_Aspect.AddPage(self.notebook_Compare_Aspect_pane_3, "Molecular Function")
        self.notebook_Compare_Aspect.AddPage(self.notebook_Compare_Aspect_pane_4, "Cellular component")
        sizer_26.Add(self.notebook_Compare_Aspect, 0, wx.ALL|wx.EXPAND, 5)
        self.notebook_Compare.SetSizer(sizer_26)
        sizer_25.Add(self.label_PlotStatistics, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 5)
        sizer_25.Add(self.combo_PlotStat, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 5)
        sizer_28.Add(self.label_2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 5)
        sizer_28.Add(self.combo_PlotType, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 5)
        sizer_25.Add(sizer_28, 0, wx.EXPAND, 0)
        sizer_30.Add(self.label_PlotStatistics_copy, 0, wx.ALL|wx.ADJUST_MINSIZE, 5)
        sizer_30.Add(self.list_PlotFA, 0, wx.ALL|wx.EXPAND|wx.ADJUST_MINSIZE, 5)
        sizer_25.Add(sizer_30, 1, wx.EXPAND, 0)
        sizer_23.Add(sizer_25, 0, wx.EXPAND, 0)
        sizer_17.Add(sizer_23, 0, wx.ALL|wx.EXPAND, 5)
        sizer_24.Add(self.bitmap_Plot, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 5)
        sizer_17.Add(sizer_24, 1, wx.ALL|wx.EXPAND, 5)
        self.notebook_Plot.SetSizer(sizer_17)
        # end wxGlade

# end of class AIGOnotebook


class AIGOFrame(wx.Frame):
    def __init__(self, *args, **kwds):
        # begin wxGlade: AIGOFrame.__init__
        kwds["style"] = wx.CAPTION|wx.CLOSE_BOX|wx.MINIMIZE_BOX|wx.MAXIMIZE|wx.MAXIMIZE_BOX|wx.SYSTEM_MENU|wx.TAB_TRAVERSAL|wx.CLIP_CHILDREN
        wx.Frame.__init__(self, *args, **kwds)
        
        # Menu Bar
        self.menubar = wx.MenuBar()
        global MENU_NEW; MENU_NEW = wx.NewId()
        global MENU_OPEN; MENU_OPEN = wx.NewId()
        global MENU_SAVE; MENU_SAVE = wx.NewId()
        global MENU_QUIT; MENU_QUIT = wx.NewId()
        global MENU_ABOUT; MENU_ABOUT = wx.NewId()
        self.ProjectMenu = wx.Menu()
        self.ProjectMenu.Append(MENU_NEW, "New", "", wx.ITEM_NORMAL)
        self.ProjectMenu.Append(MENU_OPEN, "Open", "", wx.ITEM_NORMAL)
        self.ProjectMenu.Append(MENU_SAVE, "Save", "", wx.ITEM_NORMAL)
        self.ProjectMenu.Append(MENU_QUIT, "Quit", "", wx.ITEM_NORMAL)
        self.menubar.Append(self.ProjectMenu, "&Project")
        wxglade_tmp_menu = wx.Menu()
        wxglade_tmp_menu.AppendSeparator()
        wxglade_tmp_menu.Append(MENU_ABOUT, "About", "", wx.ITEM_NORMAL)
        self.menubar.Append(wxglade_tmp_menu, "Help")
        self.SetMenuBar(self.menubar)
        # Menu Bar end
        self.statusbar = self.CreateStatusBar(6, wx.ST_SIZEGRIP)
        self.notebook = AIGOnotebook(self, -1)

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: AIGOFrame.__set_properties
        self.SetTitle("AIGO")
        _icon = wx.EmptyIcon()
        import os
        import AIGO.gui
        guiDir=os.path.dirname(AIGO.gui.__file__)
        _icon.CopyFromBitmap(wx.Bitmap("%s/AIGO.png" % guiDir, wx.BITMAP_TYPE_ANY))
        self.SetIcon(_icon)
        self.SetSize((1156, 835))
        self.statusbar.SetStatusWidths([-1, -1, -1, -1, -1, -1])
        # statusbar fields
        statusbar_fields = ["Project", "Status", "Organism", "GO", "GP", "FA"]
        for i in range(len(statusbar_fields)):
            self.statusbar.SetStatusText(statusbar_fields[i], i)
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: AIGOFrame.__do_layout
        sizer_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_1.Add(self.notebook, 1, wx.EXPAND|wx.ADJUST_MINSIZE, 0)
        self.SetSizer(sizer_1)
        self.Layout()
        # end wxGlade

# end of class AIGOFrame


class NewProjectFrame(wx.Frame):
    def __init__(self, *args, **kwds):
        # begin wxGlade: NewProjectFrame.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, *args, **kwds)
        self.NewProjectPanel = wx.Panel(self, -1)
        self.sizer_12_staticbox = wx.StaticBox(self.NewProjectPanel, -1, "")
        self.sizer_9_staticbox = wx.StaticBox(self.NewProjectPanel, -1, "")
        self.label_NewProject = wx.StaticText(self.NewProjectPanel, -1, "Project name")
        self.box_NewProject = wx.TextCtrl(self.NewProjectPanel, -1, "", style=wx.HSCROLL)
        self.label_Directory = wx.StaticText(self.NewProjectPanel, -1, "Project directory")
        self.box_Directory = wx.TextCtrl(self.NewProjectPanel, -1, "", style=wx.HSCROLL)
        self.button_DirectoryChoose = wx.Button(self.NewProjectPanel, -1, "&Browse", style=wx.BU_EXACTFIT)
        self.label_Organism = wx.StaticText(self.NewProjectPanel, -1, "Reference Organism")
        self.box_Organism = wx.TextCtrl(self.NewProjectPanel, -1, "", style=wx.HSCROLL)
        self.button_NewProjectOK = wx.Button(self.NewProjectPanel, wx.ID_OK, "")
        self.button_NewProjectCancel = wx.Button(self.NewProjectPanel, wx.ID_CANCEL, "")

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: NewProjectFrame.__set_properties
        self.SetTitle("New Project")
        self.label_NewProject.SetMinSize((165, 19))
        self.box_NewProject.SetMinSize((360, 29))
        self.label_Directory.SetMinSize((165, 19))
        self.box_Directory.SetMinSize((280, 29))
        self.label_Organism.SetMinSize((165, 19))
        self.box_Organism.SetMinSize((360, 29))
        self.NewProjectPanel.SetBackgroundColour(wx.Colour(241, 238, 238))
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: NewProjectFrame.__do_layout
        sizer_13 = wx.BoxSizer(wx.VERTICAL)
        sizer_14 = wx.BoxSizer(wx.VERTICAL)
        sizer_7 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_12 = wx.StaticBoxSizer(self.sizer_12_staticbox, wx.VERTICAL)
        sizer_6 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_9 = wx.StaticBoxSizer(self.sizer_9_staticbox, wx.VERTICAL)
        sizer_4_copy_3 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_5 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_5.Add(self.label_NewProject, 0, 0, 0)
        sizer_5.Add(self.box_NewProject, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_9.Add(sizer_5, 0, wx.ALL|wx.EXPAND|wx.ALIGN_CENTER_VERTICAL|wx.SHAPED, 10)
        sizer_4_copy_3.Add(self.label_Directory, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_4_copy_3.Add(self.box_Directory, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy_3.Add(self.button_DirectoryChoose, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 10)
        sizer_9.Add(sizer_4_copy_3, 0, wx.ALL, 10)
        sizer_14.Add(sizer_9, 0, wx.ALL|wx.EXPAND, 10)
        sizer_6.Add(self.label_Organism, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_6.Add(self.box_Organism, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_12.Add(sizer_6, 0, wx.ALL, 10)
        sizer_14.Add(sizer_12, 1, wx.ALL|wx.EXPAND, 10)
        sizer_7.Add(self.button_NewProjectOK, 0, wx.BOTTOM|wx.ADJUST_MINSIZE, 10)
        sizer_7.Add(self.button_NewProjectCancel, 0, wx.RIGHT|wx.BOTTOM|wx.ADJUST_MINSIZE, 10)
        sizer_14.Add(sizer_7, 0, wx.LEFT|wx.EXPAND|wx.ALIGN_BOTTOM, 390)
        self.NewProjectPanel.SetSizer(sizer_14)
        sizer_13.Add(self.NewProjectPanel, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_13)
        sizer_13.Fit(self)
        self.Layout()
        self.Centre()
        # end wxGlade

# end of class NewProjectFrame


if __name__ == "__main__":
    AIGO = wx.PySimpleApp(0)
    wx.InitAllImageHandlers()
    Frame = AIGOFrame(None, -1, "")
    AIGO.SetTopWindow(Frame)
    Frame.Show()
    AIGO.MainLoop()



#!/opt/anaconda1anaconda2anaconda3/bin/python
"""
AIGO.py

AIGO is a python library for
the Analysis and Inter-comparison of Gene Ontology functional annotations.
see (http://code.google.com/p/aigo).
        
Created by Michael Defoin-Platel on 21/02/2010.
Copyright (c) 2010. All rights reserved.

AIGO is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from AIGO.gui.main import startGUI


if __name__ == '__main__':

    try:
        startGUI()
        
    except Exception as e:
        print "AIGO is stopping because :"
        print "\t%s" % e.__doc__



"""
This module defines constants of general utility in the PyWeaver library.

The interpretation of each constant is dependent on the context.  In order to determine the precise
meaning of a constant, reference the documentation for the method/function that it is being used 
with.
"""

"""
Copyright 2007 Derek Ruths

This file is part of PyWeaver.

PyWeaver is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PyWeaver is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with PyWeaver.  If not, see <http://www.gnu.org/licenses/>.
"""

__all__ = ['ALL','NODES','EDGES','DIRECTED','UNDIRECTED','BOTH','IN','OUT','INFINITY']

INFINITY = float('infinity')

ALL = 'ALL'
NODES = 'NODES'
EDGES = 'EDGES'

DIRECTED = 'DIRECTED'
UNDIRECTED = 'UNDIRECTED'

BOTH = 'BOTH'
IN = 'IN'
OUT = 'OUT'



"""
Randomize.py

AIGO is a python library for
the Analysis and Inter-comparison of Gene Ontology functional annotations.
see (http://code.google.com/p/aigo).
        
Created by Michael Defoin-Platel on 21/02/2010.
Copyright (c) 2010. All rights reserved.

AIGO is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from pylab import *

from random import shuffle
from itertools import groupby, repeat

from AIGO import logger, logFun
from AIGO import allAspect

class RandomizeFA(dict):
    """
    This class provides methods to compute randomize a functional annotations.
    """

    def __init__(self, **args):
        
        # set any keyword valued parameters
        for k,v in args.items():
            self.__dict__[k] = v

    @logFun("Computing permutation of functional annotations")
    def shuffleAnnotation(self, allFA, t=10):
        """
        This method randomly re-shuffle annotation accross annotation sets.
        The coherence of the annotation sets should change.
        The size might affected if two identical indentation are assinged one set
        The other stats should remain unchanged or be marginally affected.
        """
        
        for FA in allFA:

            logger.info("\t%s" % (FA.name))

            for aspect in allAspect:
                if aspect=='All_aspects_of_GO':
                    continue

                iterKeys=flatten([list(repeat(k,len(FA.GPtoGO[aspect][k]))) for k in FA.GPtoGO[aspect].keys()])
                iterValues=list(flatten(FA.GPtoGO[aspect].values()))
                shuffle(iterValues)

                GPtoGO, GOtoGP=dict(), dict()
                for k,v in groupby(iterValues, lambda x: iterKeys.next()):
                    GPtoGO[k]= set(v)

                    for go in GPtoGO[k]:
                        if not GOtoGP.has_key(go):
                            GOtoGP[go]=set()
                        GOtoGP[go].add(k)

                FA.GPtoGO[aspect]=GPtoGO
                FA.GOtoGP[aspect]=GOtoGP

    @logFun("Computing resampling of functional annotations")
    def sampleAnnotation(self, allFA):
        """
        This method randomly sample GO annotations  keep the size of annotation sets unchange.
        """

        for FA in allFA:

            logger.info("\t%s" % (FA.name))

            for aspect in allAspect:
                if aspect=='All_aspects_of_GO':
                    continue
                
                iterKeys=flatten([list(repeat(k,len(FA.GPtoGO[aspect][k]))) for k in FA.GPtoGO[aspect].keys()])
                nbValues=len(list(flatten(FA.GPtoGO[aspect].values())))
                allNodes=FA.G.get_NodesfromAspect(aspect)
                iterValues=take(allNodes, randint(0,len(allNodes), nbValues))

                GPtoGO, GOtoGP=dict(), dict()
                for k,v in groupby(iterValues, lambda x: iterKeys.next()):
                    GPtoGO[k]= set(v)

                    for go in GPtoGO[k]:
                        if not GOtoGP.has_key(go):
                            GOtoGP[go]=set()
                        GOtoGP[go].add(k)

                FA.GPtoGO[aspect]=GPtoGO
                FA.GOtoGP[aspect]=GOtoGP



"""
Statistics.py

AIGO is a python library for
the Analysis and Inter-comparison of Gene Ontology functional annotations.
see (http://code.google.com/p/aigo).
        
Created by Michael Defoin-Platel on 21/02/2010.
Copyright (c) 2010. All rights reserved.

AIGO is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from  pylab import *

from AIGO import logger, logFun

AIGO_UNIT_PERCENT="(in %)"
AIGO_UNIT_NONE=   ""
    
class RegisterStatistics(list):
    @logFun("Preparing the registration of statistics functions")
    def __init__(self):
        
        self.all=list()
        self.name=dict()
        self.unit=dict()
        self.types=dict()

    def add(self, statistics, name, unit="", types=None):
        logger.info("Registering statistics function %s" % statistics)
        
        self.all.append(statistics)
        self.name[statistics]=name
        self.unit[statistics]=unit
        self.types[statistics]=types

    def isRegistered(self, statistics):
        return self.name.has_key(statistics)

    def getAll(self):
        return self.all

    def getStat(self, name):
        for statistics in self.all:
            if self.name[statistics]==name:
                return statistics
        return None

    def getName(self, statistics):
        return self.name[statistics]

    def getNames(self, allStatistics):
        return [self.name[statistics] for statistics in allStatistics]

    def getUnit(self,statistics):
        return self.unit[statistics]

    def getTypes(self, statistics):
        return self.types[statistics]

    def hasType(self, statistics, statType):
        return statType in self.types[statistics]

    def statOfType(self, statType):
        return [statistics for statistics in self.all if statType in self.type[statistics]]


registerStat=RegisterStatistics()

registerStat.add("obsolete",            "Not used",                  types="Analyse", unit=AIGO_UNIT_PERCENT)
registerStat.add("unconnected",         "Obsolescence",              types="Analyse", unit=AIGO_UNIT_PERCENT)
registerStat.add("removeUnconnected",   "Remove Obsolete",           types="Analyse", unit=AIGO_UNIT_NONE)
registerStat.add("redundancy",          "Redundancy",                types="Analyse", unit=AIGO_UNIT_PERCENT)
registerStat.add("removeRedundancy",    "Remove Redundancy",         types="Analyse", unit=AIGO_UNIT_NONE)
registerStat.add("coverage",            "Coverage",                  types="Analyse", unit=AIGO_UNIT_PERCENT)
registerStat.add("richness",            "Richness",                  types="Analyse", unit=AIGO_UNIT_PERCENT)
registerStat.add("numberAnnot",         "Number of Annotations",     types="Analyse", unit=AIGO_UNIT_NONE)
registerStat.add("coherence",           "Coherence",                 types="Analyse", unit=AIGO_UNIT_NONE)
registerStat.add("compactness",         "Compactness",               types="Analyse", unit=AIGO_UNIT_NONE)
registerStat.add("specificity",         "Specificity",               types="Analyse", unit=AIGO_UNIT_NONE)
registerStat.add("informationContent",  "Information Content",       types="Analyse", unit=AIGO_UNIT_NONE)

registerStat.add("venn",                "Coverage",                  types="Compare", unit=AIGO_UNIT_PERCENT)
registerStat.add("funcSim",             "Functional Similarity",     types="Compare", unit=AIGO_UNIT_NONE)








from AIGO.Statistics import registerStat as rS
from AIGO.Analyse import AnalyseFA


def batchExecute(lFunc, effector, *args, **kargs):
    for func in lFunc:
        if hasattr(effector, func):
            if isinstance (effector, AnalyseFA) and not rS.isRegistered(func):
                print "Warning, call of an unregistered statistics : %s"  % func
                
            getattr(effector, func)(*args, **kargs)



from pylab import *

from time import strftime

from AIGO import allAspect

class ReportFA():

    def __init__(self, **args):

        # set any keyword valued parameters
        for k,v in args.items():
            self.__dict__[k] = v

    def printStatistics(self, allFA, exportList):
        for aspect in allAspect:
            
            #Write Headers
            print "\n=========================================================================="
            print "Properties of %s Functional Annotations for %s" % (self.organism, aspect)
            print "\tMeasure",
            for name in [FA.name for FA in allFA]:
                print"\t%s" % name,

            #Write Measures
            for meas in exportList:
                print "\n\t%s" % meas,

                for FA in allFA:
                    if FA.has_key(meas):
                        d=FA[meas][aspect]
                        if type(d)==list:
                            d=mean(d)

                        print "\t%.2f" % d,
                    else:
                        print "\t-",
            print "\n=========================================================================="
    

    def saveStatistics(self, allFA, exportList):
        import xlwt

        title_f = xlwt.Font()
        title_f.height = 200
        title_f.name = 'Verdana'
        title_f.bold= True
        title_xf = xlwt.easyxf('align: vert centre, horiz center')
        title_xf.font = title_f

        bold_f = xlwt.Font()
        bold_f.height = 180
        bold_f.name = 'Times New Roman'
        bold_f.bold= True
        bold_xf = xlwt.easyxf('align: vert centre, horiz center')
        bold_xf.font = bold_f


        number_xf=xlwt.easyxf('align: vert centre, horiz center')
        number_xf.num_format_str="0.00"
        
        norm_xf=xlwt.easyxf('align: vert centre, horiz center')

        
        wb = xlwt.Workbook()

        for aspect in allAspect:
            
            ws=wb.add_sheet(aspect)

            #Write Headers        
            tit="Properties of %s Functional Annotations for %s" % (self.organism, aspect)
            ws.col(0).width = len(tit) * 256            
            ws.write(0,0, tit , title_xf)
            ws.write(1,0, "Measure", bold_xf)
            for i,name in enumerate([FA.name for FA in allFA]):
                ws.write(1,1+i, name, bold_xf)
                ws.col(1+i).width = 0x0d00 + 210

            offset=2
            #Write Measures
            for meas in exportList:
                ws.write(offset,0, meas, norm_xf)

                for i,FA in enumerate(allFA):
                    d=FA[meas][aspect]
                    if type(d)==list:
                        d=mean(d)
                        
                    ws.write(offset,1+i, d, number_xf)

                offset=offset+1

                
        fileName="%s/export_%s_%s.xls" % (self.outDir, self.name, self.organism)
        wb.save(fileName)

        



